@@ -5,10 +5,10 @@
 
 package Object::Pad::MOP::Class;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 # This is an XS-implemented object type provided by Object::Pad itself
 require Object::Pad;
